sphinx.ext.oldcmarkup – Compatibility extension for old C markup — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# `sphinx.ext.oldcmarkup` – Compatibility extension for old C markup

New in version 1.0.

This extension is a transition helper for projects that used the old (pre-domain) C markup, i.e. the directives like `cfunction` and roles like `cfunc`. Since the introduction of domains, they must be called by their fully-qualified name (`c:function` and `c:func`, respectively) or, with the default domain set to `c`, by their new name (`function` and `func`). (See The C Domain for the details.)

If you activate this extension, it will register the old names, and you can use them like before Sphinx 1.0. The directives are:

- `cfunction`
- `cmember`
- `cmacro`
- `ctype`
- `cvar`

The roles are:

- `cdata`
- `cfunc`
- `cmacro`
- `ctype`

However, it is advised to migrate to the new markup – this extension is a compatibility convenience and will disappear in a future version of Sphinx.

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »